/*************************************************************************
 *   #Include inc_AutoReLoad.AHK
 *
 *   Datum: 2005-04-27
 *   Autor: Kalle Koseck
 *   Vers:  0.10
 *          0.11 2005-06-22 Timers external fct; Globals
 *   AHK:   1.0.35+
 *
 *   PnP:   yes
 *          #Include this file in your auto-execute section
 *
 *          search for user changes: NextUserChange
 *
 *************************************************************************
 *
 *   Initialize support for auto-loading of changed script files
 *   Load script automatically when changed (and saved) by the user
 *
 *   - several computers execute the same script delivered on a mapped drive
 *   - archive bit is not changed
 *   - if errors occur in changed script the old script keeps running;
 *     not the user sitting at the computers are warned
 *     (who may don't know what this warning means);
 *     message is sent to the administrator
 *   - internal changes by saving INI values (that may be stored in
 *     the main file) do not reload this file
 *
 *   Thanks to:
 *     skrommel who published the idea of auto Reloading and to
 *     Chris for his 5-Star-Help and personal information
 *
 *   Remarks:
 *   - If you want to specify a different time interval for looking for
 *     an updated source file, set the value prior to invoking the
 *     #Include file:
 *
 *       TimeInterval = 60000  ; wait 60 seconds
 *       #Include inc_AutoReLoad.AHK
 *
 *   Comment on network installations:
 *
 *   - I don't recommend to use the files "A"rchive attribute for
 *     detection of changes *  it does not work with network installations
 *     where many computers use the same .AHK source and autoload those.
 *
 *   - a network installation should use a separate INI file in the
 *     users personal directory or the computers directory
 *
 * --------------------------------------------------------------
 *   This part of code has to be inserted (e.g. via #Include)
 *   in the AHKs auto-execute code. Appended functions are automatically
 *   skipped; they do not have to be moved to the Gosub's part of
 *   the code.
 *
 *   If you want to disable the tooltip "<file> loaded again",
 *   set in you calling code after (!) calling the #Include:
 *
 *     #Include inc_AutoReLoad.AHK
 *     AutoReLoad_Tooltip := False
 * --------------------------------------------------------------
 *   Initialisiert Untersttzung, um AHK-Files automatisch neu
 *   zu laden.
 *
 *   Wird dieses bzw. das Master-File durch Speicherung der
 *   INI-Werte gendert, so fhrt dieses nicht zu einem erneuten
 *   Laden der Source.
 *
 *   Dieser Code sollte vollstndig (also auch einschliesslich
 *   der anhngenden Funktionen) ber ein #Include im Kopf des
 *   jeweiligen AHK-Files eingebunden werden. Die Funktionen
 *   werden dann selbstndig bersprungen.
 *
 *   Bemerkung:
 *   - Wenn Sie ein anderes als das hier vorgegebene Zeitintervall (z.B.
 *     5000 msek = 5 sek. benutzen wollen, so weisen Sie zuerst dem Intervall
 *     einen neuen Wert zu und #Includen sie diese Routinen anschliessend:
 *
 *       TimeInterval = 60000  ; warte 60 sek
 *       #Include inc_AutoReLoad.AHK
 *
 *   Bemerkung zu einer Installation auf einem Netzwerk-Laufwerk:
 *
 *   - Die Benutzung des "A"rchiv-Attributs funktioniert nicht, um genderte
 *     Files festzustellen, wenn mehrere Rechner gleichzeitig darauf
 *     zugreifen. Man sollte dafr die Zeit fr den letzten Zugriff
 *     (last access) benutzen, die nicht durch den prfenden Rechner
 *     gendert werden muss.
 *
 *   - Eine Netzwerk-Installation darf seine Parameter nicht in der
 *     AHK-Source speichern (diese Mglichkeit besteht), damit jeder
 *     Rechner seine individuellen Parameter benutzen kann.
 *
 *
 *   Wenn Sie die automatische Meldung ber das erneute Einlesen der
 *   AHK-Source nicht erhalten wollen, setzen Sie nach dem Aufruf
 *   fr das #Include:
 *
 *     #Include inc_AutoReLoad_Error.ahk
 *     #Include inc_AutoReLoad.AHK
 *     AutoReLoad_Tooltip := True
 */
	#Include inc_Error.ahk
	
	AutoReLoad_Init( TimeInterval )
/*
 * **************************************************************************
 */
AutoReLoad_Init( TimeInterval )
{
	; if you want to monitor the values of the internal variables:
	; enable "Global" and comment out the lines with "Static" !
	; Global
	; ----- #IncludeAgain ,, [Globals] ------------------------------------
	Global AutoReLoad_Tooltip
	Global AutoReLoad_FileTimeOld, AutoReLoad_TimeInterval
	; ---------------------------------------------------------------------

	AutoReLoad_Tooltip := True
	FileGetTime, AutoReLoad_FileTime , %A_ScriptFullPath%, M
	AutoReLoad_FileTimeOld := AutoReLoad_FileTime
	; if not specified in main program

	; <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
	; <<<<< NextUserChange (more)
	; adjust the default time interval here
	If ( TimeInterval = "" )
		AutoReLoad_TimeInterval = 5000

	Else
		AutoReLoad_TimeInterval = TimeInterval
	SetTimer, AutoReLoad_Timer, %AutoReLoad_TimeInterval%

Return   ; of function AutoReLoad_Init

/*
 ***************************************************************************
 *         Manuelles Neuladen: <Ctrl-R> darf jedoch nur von einem Programm
 *         benutzt werden: deshalb hier nicht freigeschaltet.
 * ^R::    ;  Reload manually by <Ctrl-R> (can only be used by ONE .ahk)
 ***************************************************************************

 ***************************************************************************
 *  only functions are jumped over in an #Include,
 *  but SetTimer needs a label; so we provide a label to jump to.
 *  (not really clean but tricky and it works)
 * --------------------------------------------------------------------------
 *  leider werden nur Funktionen automatisch bersprungen; das SetTimer-
 *  Kommando bentigt jedoch ein (Gosub-) Label, also geben wir ihm eines
 *  innerhalb einer Funktion
 *  (nicht ganz sauber programmiert, aber ganz trickreich, jedenfalls gehts)
 */
AutoReLoad_Timer:
	; keep code in a separate function
	; or use the assume all variable as "Global" statement
	; otherwise wouldnt you get access to your variables
	AutoReLoad_fTimer()
	Return
}   ; END of function AutoReLoad_Init
/*
 *************************************************************************
 */
AutoReLoad_fTimer()
{
	; ----- #IncludeAgain ,, [GlobalAutoReLoad] ---------------------------
	Global AutoReLoad_Tooltip
	Global AutoReLoad_FileTimeOld, AutoReLoad_TimeInterval
	; ---------------------------------------------------------------------

	FileGetTime, AutoReLoad_FileTime , %A_ScriptFullPath%, M  ; M=Modified A=Access-Last C=Creation
	; Tooltip %AutoReLoad_FileTime%  : %ERRORLEVEL%
		StringSplit, AutoReLoad_Array_, A_ScriptFullPath ,\, ,
		AutoReLoad_Drive = %AutoReLoad_Array_1%
		;tooltip %A_ScriptFullPath%`n%AutoReLoad_Array_0%`n%AutoReLoad_Array_1%`n%AutoReLoad_Array_2%
	If ( ERRORLEVEL <> 0 )
	{
		Tooltip Drive %AutoReLoad_Drive% not available
		; Tooltip Laufwerk %AutoReLoad_Drive% nicht verfuegbar
	}
	Else
	{
		; Tooltip %FileTime%  %A_ScriptFullPath% ;**kk
		If ( AutoReLoad_FileTimeOld <> AutoReLoad_FileTime )
		{
			AutoReLoad_FileTimeOld := AutoReLoad_FileTime

			; !! you can use the new loaded script, when Traytip vanishes !!
			If AutoReLoad_Tooltip
			{
				TrayTip ,,"%vProgram_NNamExt%" will be loaded
				; ToolTip "%vProgram_NNamExt%" will be loaded
				; SplashTextOn, 400,50,, "%vProgram_NNamExt%" will be loaded
				Sleep 2500
			}
			Reload  ; and cancel Tooltip
			AutoReload_Error()  ; executed only if Reload fails
		}
		Else
			If fError_Display_Get_Display()
				Tooltip   ; clear message
	}
Return  ; of Timer-Sub AutoReLoad_Timer
}

/*************************************************************************
 * <<<<< NextUserChange (last)
 *************************************************************************
 *  File:  AutoReload_Error.AHK
 *  Datum: 2005-04-27 13:00
 *  Autor: Kalle Koseck
 *  Vers:  0.10
 *  AHK:   1.0.31+
 *************************************************************************
 *  Example may be placed in an installation dependent #Include file
 *  or just left in place if you can use it for all of your installations.
 * /

AutoReload_Error()
{
	; Global AutoReload_TheAdministratorsComPuter

	; <<<<< Correct the _ComPuter's name
	; <<<<< to your administrators
	; <<<<< computer name !
	AutoReload_TheAdministratorsComPuter = RM02MOT100108

	; Tooltip Reload: %Computername%
	Sleep 200
	If %Computername% = %AutoReload_TheAdministratorsComPuter%
	{
		Tooltip
		(
		`n**************************************************`n
		*** Error Reloading AHK-Script ***
		"%vProgram_NNamExt%"
		`n**************************************************`n
		)
	}
	Else
	{
		Run
		(
		Net Send %TheAdministratorsComPuter%
		`n`n*** Error Reloading AHK-Script`n`n"%vProgram_NNamExt%"`n`n
		,,Hide
		)
	}
}
/*
 *************************************************************************
 */

