/********************************************************************
 *  File:     #Include inc_Error.AHK
 *  Autor:    Kalle Koseck
 *  License:  GPL / GNU General Public License
 *  Datue:    2005-06-25
 *  PnP:      yes, no changes needed
 *
 ********************************************************************
 *  fError_Display_Set( vError_Number, vString )
 *  Display_Do := fError_Display_Get_Display()
 *
 *  internal use ONLY:
 *  fError_Display_Timer_On()
 *  fError_Display_Timer_Off()
 *
 ********************************************************************
 *
 *  Call:
 *
 *    fError_Display_Set( vError_Number, vString )
 *
 *  Sets the Error-String to a global variable
 *  inhibits other threats from clearing the ToolTip
 *
 *  Input:
 *
 *    vError_Number   INTEGER Variable or Constant
 *                    <> 0: set _Number and _String into Global
 *
 *    vString         CHARACTER Variable or Constant
 *                    <> "": display in Tooltip, when _Enable
 *
 *  Output:
 *
 *    -NONE-
 ********************************************************************
 */

fError_Display_Set( vError_Number, vString )
{

	Global vErrors_Tooltip_Enable    , vErrors_Tooltip_Show
	Global vErrors_LastError_String  , vErrors_LastError_Number

;--------------------------------------------------------------------
	If vError_Number   ; <> 0
	{
		vErrors_LastError_String := vString
		vErrors_LastError_Number := vError_Number
	}

;--------------------------------------------------------------------
	If vString   ; <> ""
		If vErrors_Tooltip_Enable
		{
			If vErrors_Tooltip_Show =
				vErrors_Tooltip_Show := 1
			If vErrors_Tooltip_Show
			{
				fError_Display_Timer_On( vError_Number )
				Tooltip %vString%
			}
		}

	;ListVars
	Return

}

/********************************************************************
 *  Autor:    Kalle Koseck
 *  License:  GPL / GNU General Public License
 *  Date:     2005-06-25
 *
 *  Call:
 *
 *    fError_Display_Timer_On()
 *
 *      Switches Timer ON, disables display via Tooltip
 *
 *    fError_Display_Timer_Off()
 *
 *      Switches Timer OFF, allows display via Tooltip
 *
 *  Input / Output:
 *
 *    -NONE-
 *
 ********************************************************************
 */
fError_Display_Timer_On( vError_Number )
{
	Global vErrors_Tooltip_TimeInterval   , vErrors_Tooltip_Show

	; default if not set (before or after) by the user
	If vErrors_Tooltip_TimeInterval_default =
		vErrors_Tooltip_TimeInterval_default := 15000

	If vError_Number   ; <> 0: errors detected
		vErrors_Tooltip_TimeInterval := vErrors_Tooltip_TimeInterval_default
	Else
		vErrors_Tooltip_TimeInterval := 5000

	SetTimer mError_Display_Timer, %vErrors_Tooltip_TimeInterval%
	vErrors_Tooltip_Show := False
Return

; Jump here after TimeInterval has elapsed
mError_Display_Timer:
	fError_Display_Timer_Off()
	Return
}

/********************************************************************
 *  SHOULD be a separate function !!
 */
fError_Display_Timer_Off()
{
	Global vErrors_Tooltip_TimeInterval   , vErrors_Tooltip_Show

	SetTimer mError_Display_Timer, Off
	vErrors_Tooltip_Show := True
Return

}


/********************************************************************
 *  Autor:    Kalle Koseck
 *  License:  GPL / GNU General Public License
 *  Date:     2005-06-25
 *
 *  Call:
 *
 *    Display_Do := fError_Display_Get_Display()
 *
 *  Returns, if a display by "Tooltip" is allowed to do.
 *
 *  Input:
 *
 *    -NONE-
 *
 *  Output:
 *
 *    fError_Display_Get_Display()
 *                    LOGICAL Return
 *                    0: don't display via "Tooltip",
 *                       other routine displays now
 *                    1: allowed to display
 *
 *  Example:
 *
 *  You included Tooltip-messages for debug purposes and you don't
 *  want to have the tooltips be deleted or overwritten by
 *  another thread. Include the following code to you program:
 *
 *     If User_Error_Occured
 *        If fError_Display_Get_Display()
 *           Tooltip Display next message
 *
 *  Remember:
 *  ---------
 *  Usage of this function prevents all messages that should be
 *  output during an time interval.
 *
 ********************************************************************
 */
fError_Display_Get_Display()
{
	Global vErrors_Tooltip_Show

	If vErrors_Tooltip_Show =
		vErrors_Tooltip_Show := 1

	Return vErrors_Tooltip_Show
}
