#SingleInstance
Matrix_Test()


/*
 *************************************************************************
 *
 
 Achtung: dies hier geht nicht !!
 
Matrix_1_Operate( Action, Pa_InOut_Value, Pa_Arr_Name )
{
	Global
	
	Action = INIT / ...
	Pa_Arr_IO_1 :=   ; RD and WR Filename
	Pa_Arr_IO_2 :=   ; # rows
	Pa_Arr_IO_3 :=   ; # columns
	Pa_Arr := Pa_Arr_Name
	
	MsgBox,, Sub Matrix_Operate, _Operate Action "Pa_Arr_IO" "%Pa_Arr%" 1
	Matrix_Operate( Action, "Pa_Arr_IO", "Pa_Arr" )

	Return
}
 */

/*
 *************************************************************************
 *  File:     inc_Matrix.ahk
 *  Author:   Kalle Koseck
 *  License:  GPL / GNU General Public License
 *  Date:     2009-06-09
 *  Revision: 
 *
 *  Operate on multi-dimensional Matrices:
 *  Insert / Replace / Find / Delete complete rows
 *
 *  The number of rows and columns is not limited (except by memory).
 *
 *
 *  Para1: String:  Action
 *
 *         ======================================================================
 *         INIT  Columns         Set the number of Columns (INITIALIZATION)
 *                               HAS TO BE CALLED before working with the matix
 *                               
 *                        _IO_1: Filename for "RD" and "WR"
 *                               has to be supplied
 *                               
 *                        _IO_2: number of rows
 *                               =0: clear all (possibly existing contents)
 *                               >0: set number of Rows to value
 *                                   = Keep the information in that number of Rows
 *                               "": (empty) Keep the old number of __Rows
 *                                   if do not exist: set to 0
 *                               
 *                        _IO_3: number of columns (must be > 0)
 *                               
 *                               The matrix can be redimensioned by this command.
 *         ======================================================================
 *                               
 *         INS   Insert/Replace  return slot-no of inserted/replaced token in Matrix
 *                               -- if a matching col 1 is found the row is replaced
 *                               -- if an empty row in the matrix is found the parameters
 *                                  are inserted at that place
 *                               -- otherwise the row is appended to the matrix
 *           .._IO_1 to .._IO_n: the parameters to insert or replace
 *                   fct Return: the line number found; 0=did not find
 *                               
 *         FND   Find            return slot-no for match: search col 1 ONLY
 *         FND*  Find multiple   return slot-no for match: search all cols <> empty
 *                               (all .._IO_x that are not empty on input)
 *
 *                        Input:
 *                      .._IO_1: contains string to be searched for (in col 1)
 *           .._IO_2 to .._IO_n: (nonblank) the other parameters in the row searched for
 *                      
 *                       Output:
 *           .._IO_2 to .._IO_n: the other parameters in the row found
 *                   fct Return: the line number found; 0=did not find
 *                               
 *         ROWGET RowGet         return the row of the matrix in _IO_
 *                               1 <= RowNo <= Matrix__Rows
 *                        Input:
 *                       ..IO_1: number of row whose parameter are to be returned
 *                               
 *                       Output:
 *           .._IO_1 to .._IO_n: values in the wanted row
 *                               empty: RowNo outside matrix
 *                   fct Return: 1 = Row exists; 0 = RowNo outside matrix
 *                               
 *         ROWDEL RowDelete      delete all parameters in a row leaving them empty
 *                        Input:
 *                       ..IO_1: number of row whose parameter are to be returned
 *                       Output:
 *                   fct Return: 1 = Row exists; 0 = RowNo outside matrix
 *                               
 *         DEL   Delete          find and delete a row
 *                   fct Return: the line number found; 0=did not find
 *         
 *         RD    Read            read the Matrix from file
 *                      .._IO_1: contain the filename
 *                               empty: had to be set in the INIT command
 *                               
 *         WR    Write           write the Matrix to file
 *                      .._IO_1: contain the filename
 *                               empty: had to be set in the INIT command
 *                               
 *         DISP  Display         the contents of the Matrix in a messagebox
 *
 *  Para2: String:  Pa_IO_Name
 *         Name of the parameters to be inserted / found
 *         e.g. AW_Hwnd_IO_1 .. AW_Hwnd_IO_3
 *         for a 3-columns matrix
 *
 *  Para3: String:  Pa_Arr_Name
 *         Name of the matrix with  .._Row_Col
 *         e.g. AW_Hwnd_1_1, AW_Hwnd_1_2, AW_Hwnd_1_3, .. AW_Hwnd_5_3
 *         for a 3-columns matrix
 *         
 *  Call:
 *
 *  AW_FullScreen_IO_1 = Matrix_Input_File.INI
 *	Matrix_Operate( "RD", "AW_FullScreen_IO", "AW_FullScreen" )
 *
 *************************************************************************
 */
Matrix_Operate( Action, Pa_IO_Name, Pa_Arr_Name )
{
	Global
	
	Matrix_Debug = 0
	Matrix_IO_Value_1 := %Pa_IO_Name%_1

	; listvars
	; MsgBox,, Sub Matrix_Operate, __Rows %Matrix__Rows%

	;==================================================================
	If ( Action = "INIT" )   ; define number of columns
	;==================================================================
	{
		If ( mMatrix__Filename( Action, %Pa_IO_Name%_1 ) = 0 )   ; .._1
			%Pa_Arr_Name%__File := Matrix__File
		Matrix__Rows := %Pa_IO_Name%_2
		; --- keep old value - if exist
		If ( Matrix__Rows = "" )
			Matrix__Rows := %Pa_Arr_Name%__Rows
		If ( Matrix__Rows = "" )
		{
			Matrix__Rows = 0
			If ( Matrix_Debug )
			MsgBox,, Sub Matrix_Operate,  INIT+Rows=0 "%Matrix__File%" "%Matrix__Rows%" "%Matrix__Cols%"
		}
		%Pa_Arr_Name%__Rows := Matrix__Rows

		Matrix__Cols := %Pa_IO_Name%_3
		%Pa_Arr_Name%__Cols := Matrix__Cols
		
		If ( Matrix__Rows = 0 )
			If ( Matrix_Debug )
			MsgBox,, Sub Matrix_Operate,  INIT "%Matrix__File%" "%Matrix__Rows%" "%Matrix__Cols%"

		Return 0
	}

	;==================================================================
	If ( Action = "RD" )   ; READ FILE
	;==================================================================
	{
		if ( mMatrix__Filename( Action, %Pa_IO_Name%_1 ) <> 0 )
			Return 1
		; FileReadLine, Matrix__Rows       , %Matrix__File%, 1
		FileReadLine, Matrix__Cols  , %Matrix__File%, 1
		
		%Pa_Arr_Name%__Rows := Matrix__Rows

		Cnt_Line := 2
		Cnt_While_Row := 1
		Error_Read := 0
		While, 1    ; for all rows of the Matrix
		{
			Cnt_While_Col := 0
			While, Cnt_While_Col < Matrix__Cols
			{
				Cnt_While_Col += 1

				FileReadLine, Data  , %Matrix__File%, %Cnt_Line%
				Error_Read := Errorlevel
				If ( Error_Read <> 0 )
				{
					If ( Cnt_While_Col <> 1 )
					{
						MsgBox 16
						, Error in method "Matrix_Operate" 
						, Reading file: "%Matrix__File%"`n`nLine: %Cnt_Line%`n`nShould be %Matrix__Cols% lines per entry
					}
					Break
				}
				; If ( Matrix_Debug )
				; MsgBox,, Sub Matrix_Operate,  %Cnt_While_Row%-%Cnt_While_Col%  %Data%  Errorlevel: %Errorlevel%
				%Pa_Arr_Name%_%Cnt_While_Row%_%Cnt_While_Col% := Data

				Cnt_Line += 1
			}
			If ( Error_Read <> 0 )
				Break
			Else
				Cnt_While_Row += 1
		}
		
		Cnt_While_Row := Cnt_While_Row - 1
		%Pa_Arr_Name%__Cols := Matrix__Cols
		%Pa_Arr_Name%__Rows := Cnt_While_Row
		; If ( Matrix_Debug )
		; MsgBox,, Sub Matrix_Operate,  Col %Matrix__Cols%  Row %Cnt_While_Row%
		Return 0
	}

	;==================================================================

	Matrix__Cols := %Pa_Arr_Name%__Cols
	If ( Matrix__Cols = "" OR Matrix__Cols <= 0 )
	{
		MsgBox 16
			, Error in method "Matrix_Operate" 
			, Sub Matrix_Operate: "%Pa_Arr_Name%"`n`nNumber of columns not initialized by call with "INIT"`n`nVariable:  %Pa_Arr_Name%__Cols = "%Matrix__Cols%"
		Return 1
	}
	; If ( Matrix_Debug )
	; MsgBox,, Sub Matrix_Operate, __Cols = "%Matrix__Cols%"

	Matrix_Content_1 := %Pa_Arr_Name%_%Cnt_While_Row%_1
	Matrix__Rows := %Pa_Arr_Name%__Rows    ; number of rows in array
	If ( Matrix__Rows = "" )
		Matrix__Rows = 0

	;==================================================================
	If ( Action = "DISP" )   ; DISPLAY
	;==================================================================
	{
		Data = Sub Matrix_Operate DISP "%Pa_Arr_Name%"`n`n
		If ( Matrix__Rows <= 0 )
			Data = %Data%is empty`n
		Cnt_While_Row := 1
		While, Cnt_While_Row <= Matrix__Rows
		{
			Data = %Data%Line %Cnt_While_Row%
			Cnt_While_Col := 1
			While, Cnt_While_Col <= Matrix__Cols
			{
				Data := Data " / " %Pa_Arr_Name%_%Cnt_While_Row%_%Cnt_While_Col%
				Cnt_While_Col += 1
			}
			Data = %Data%`n   ; append <Return>
			Cnt_While_Row += 1
		}
		; with exclamation mark "!"
		MsgBox 64, Sub Matrix_Operate Display: %Pa_Arr_Name%, %Data%
		; FileAppend, %Data%`n   ,%Matrix__File%
		Return 0
	}

	;==================================================================
	If ( Action = "WR" )   ; WRITE FILE
	;==================================================================
	{
		if ( mMatrix__Filename( Action, %Pa_IO_Name%_1 ) <> 0 )
			Return 1
		FileDelete, %Matrix__File%
		FileAppend, %Matrix__Cols%`n   ,%Matrix__File%  ; and append CR,LF
		
		Cnt_While_Row := 1
		While, Cnt_While_Row <= Matrix__Rows   ; for all rows of the Sub Matrix_Operate
		{
			Cnt_While_Col := 1
			While, Cnt_While_Col <= Matrix__Cols
			{
				Data := %Pa_Arr_Name%_%Cnt_While_Row%_%Cnt_While_Col%
				FileAppend, %Data%`n   ,%Matrix__File%
				Cnt_While_Col += 1
			}
			Cnt_While_Row += 1
		}
		Return 0
	}
	
	;==================================================================
	Else If ( Action = "ROWGET" )   ; RETURN THE VALUES OF THIS ROW
	;==================================================================
	{
		If ( Matrix_IO_Value_1 >= 1  AND  Matrix_IO_Value_1 <= Matrix__Rows )
		{
			Matrix_Return := Matrix_IO_Value_1
			; --- return the row found to the _IO_ vars
			Cnt_While_Col := 1
			Matrix_Txt =
			While, Cnt_While_Col <= Matrix__Cols
			{
				Matrix_Txt .= Cnt_While_Col ": " %Pa_Arr_Name%_%Matrix_IO_Value_1%_%Cnt_While_Col% " / "
				%Pa_IO_Name%_%Cnt_While_Col% := %Pa_Arr_Name%_%Matrix_IO_Value_1%_%Cnt_While_Col%
				Cnt_While_Col += 1
			}
		}
		; --- row not in matrix: clear all _IO_ & return error
		Else
		{
			Matrix_Return := 0
			Cnt_While_Col := 1
			While, Cnt_While_Col <= Matrix__Cols
			{
				%Pa_IO_Name%_%Cnt_While_Col% :=
				Cnt_While_Col += 1
			}
		}
		; msgbox  Sub Matrix_Operate %Action% "%Matrix_Return%": %Matrix_Txt%
		Return %Matrix_Return%
	}

	;==================================================================
	Else If ( Action = "ROWDEL" )   ; DELETE THE VALUES OF THIS ROW
	;==================================================================
	{
		If ( Matrix_IO_Value_1 >= 1  AND  Matrix_IO_Value_1 <= Matrix__Rows )
		{
			Matrix_Return := Matrix_IO_Value_1
			; --- return the row found to the _IO_ vars
			Cnt_While_Col := 1
			While, Cnt_While_Col <= Matrix__Cols
			{
				%Pa_Arr_Name%_%Matrix_IO_Value_1%_%Cnt_While_Col% :=
				Cnt_While_Col += 1
			}
		}
		; --- row not in matrix: clear all _IO_ & return error
		Else
		{
			Matrix_Return := 0
		}
		If ( Matrix_IO_Value_1 = Matrix__Rows )
		{
			Matrix__Rows -= 1
			%Pa_Arr_Name%__Rows := Matrix__Rows
		}
		; msgbox  Sub Matrix_Operate %Action%: %Matrix_Return%/%Matrix__Rows%
		Return %Matrix_Return%
	}


	;==================================================================
	
	; ALL OTHER FUNCTIONS:  "INS"  "FND"  "DEL"
	
	; ========== Start of Row-While ==========
	Matrix_Found = 0
	Matrix_Return = 0
	
	Remember_empty_Row := 0
	Cnt_While_Row := 1
	
	While, Cnt_While_Row <= Matrix__Rows
	{
		Matrix_Content_1 := %Pa_Arr_Name%_%Cnt_While_Row%_1
		If ( Matrix_Content_1 = "" AND Remember_empty_Row = 0 )   ; Row is empty
			Remember_empty_Row := Cnt_While_Row

		; If ( Action = "FND" )
		; If ( Matrix_Debug )
		;	MsgBox,, Sub Matrix_Operate,  %Action%: %Pa_Arr_Name%_1_%Cnt_While_Row%  %Matrix_Content_1% = %Matrix_IO_Value_1%

		;==================================================================
		; this handle is not valid: entry is free
		If ( Action = "INS" )   ; INSERT or REPLACE
		;==================================================================
		{
			If ( Matrix_Content_1 = Matrix_IO_Value_1 )   ; REPLACE
			{
				GoSub Matrix_ROWINS
				If ( Matrix_Return <> 0 )   ; # Row
					Break

			}
		}

		;==================================================================
		Else If ( Action = "FND" )   ; FIND IN THE 1. COLUMN
		;==================================================================
		{
			If ( Matrix_Content_1 = Matrix_IO_Value_1 )
			{
				Cnt_While_Col := 2
				While, Cnt_While_Col <= Matrix__Cols
				{
					%Pa_IO_Name%_%Cnt_While_Col% := %Pa_Arr_Name%_%Cnt_While_Row%_%Cnt_While_Col%
					Cnt_While_Col += 1
				}
				Matrix_Found := Matrix_Content_1
				Matrix_Return := Cnt_While_Row
			}
			
			; if the first line and not found: clear all variables
			Else If ( Cnt_While_Row = 1 )
			{
				Cnt_While_Col := 2
				While, Cnt_While_Col <= Matrix__Cols
				{
					%Pa_IO_Name%_%Cnt_While_Col% =
					Cnt_While_Col += 1
				}
			}
		}

		;==================================================================
		Else If ( Action = "FND*" )   ; FIND IN ALL NOT EMPTY COLUMNS
		;==================================================================
		{
			GoSub Matrix_FNDStar
			If ( Matrix_Return <> 0 )   ; # Row
				Break
		}

		;==========================================================
		Else If ( Action = "DEL" )   ; DELETE
		;==========================================================
		{
			If ( Matrix_Content_1 = Matrix_IO_Value_1 )
			{
				; If ( Matrix_Debug )
				; MsgBox,, Sub Matrix_Operate,  now to delete: index %Cnt_While_Row%  %Matrix_Content_1% = %Matrix_IO_Value_1%
				Cnt_While_Col := 1
				While, Cnt_While_Col <= Matrix__Cols
				{
					%Pa_Arr_Name%_%Cnt_While_Row%_%Cnt_While_Col% = 
					Cnt_While_Col += 1
				}
				Matrix_Found := 1
				Matrix_Return := Cnt_While_Row

				; the last entry is to be deleted
				If ( Cnt_While_Row = Matrix__Rows )
				{
					Matrix__Rows -= 1
					If ( Matrix_Debug )
					MsgBox,, Sub Matrix_Operate,  Action %Action%  Matrix__Rows-1: %Matrix__Rows%
				}
				Break
			}
		}
		Cnt_While_Row += 1
	}
	; ========== End of While ==========

	;================================================================================
	If ( Action = "INS" )   ; no empty slot found: APPEND to Matrix   ; INSERT
	;================================================================================
	{
		If ( Matrix_Found = 0 )
		{
			If ( Remember_empty_Row > 0 )
			{
				Cnt_While_Col := Remember_empty_Row   ; write into table
				Matrix_Return := Cnt_While_Col
			}
			Else
			{
				Matrix__Rows += 1
				Cnt_While_Row := Matrix__Rows   ; append to the end of the table
				Matrix_Return := Matrix__Rows
			}
			GoSub Matrix_ROWINS
		}
	}

	;================================================================================

	%Pa_Arr_Name%__Rows := Matrix__Rows
	If ( Matrix__Rows = 0 )
		If ( Matrix_Debug )
		MsgBox,, Sub Matrix_Operate,  Action %Action%  Matrix__Rows ist 0

	; If ( Matrix_Debug )
	; {
	; listvars
	; MsgBox,, Sub Matrix_Operate,  %Pa_Arr_Name%_%Cnt_While_Row%_%Cnt_While_Col% := %Pa_IO_Name%_%Cnt_While_Col%
	; }

	Cnt_While_Row := 1
	
	While, Cnt_While_Row <= Matrix__Rows
	{
		Matrix_Content_1 := %Pa_Arr_Name%_%Cnt_While_Row%_1
	}

	Return %Matrix_Return%

; -----------------------------------------------------------------------------------------------	
Matrix_FNDStar:
	Matrix_Txt := "R:" Cnt_While_Row ":" Matrix_Content_1
	; msgbox  Sub Matrix_Operate %Action%: %Matrix_Txt%   %Matrix_Content_1% = %Matrix_IO_Value_1%
	; --- the first col is found
	If ( Matrix_Content_1 = Matrix_IO_Value_1 )
	{
		Matrix_ThisRow := 1
		; --- for all cols: search through act. row; skip empty .._IO_x
		Cnt_While_Col := 2
		While, Cnt_While_Col <= Matrix__Cols
		{
			Matrix_IO_Value_N := %Pa_IO_Name%_%Cnt_While_Col%   ; the _IO_ value to be searched for
			Matrix_Col_N := %Pa_Arr_Name%_%Cnt_While_Row%_%Cnt_While_Col%   ; this row / all cols
			; Listvars
			; msgbox Col %Pa_IO_Name%_%Cnt_While_Col%  Val "%Matrix_IO_Value_N%" "%Matrix_Col_N%"
			If ( Matrix_IO_Value_N <> "" )
			{
				Matrix_Txt .= "  (" Matrix_IO_Value_N ") " Matrix_Col_N
				If ( Matrix_Col_N <> Matrix_IO_Value_N )
				{
					Matrix_ThisRow := 0
				}
			}

			; %Pa_IO_Name%_%Cnt_While_Col% := %Pa_Arr_Name%_%Cnt_While_Row%_%Cnt_While_Col%
			Cnt_While_Col += 1
		}
		If ( Matrix_ThisRow )
		{
			Matrix_Found := Matrix_Content_1
			Matrix_Return := Cnt_While_Row
			; --- return the row found to the _IO_ vars
			Cnt_While_Col := 1
			While, Cnt_While_Col <= Matrix__Cols
			{
				%Pa_IO_Name%_%Cnt_While_Col% := %Pa_Arr_Name%_%Cnt_While_Row%_%Cnt_While_Col%
				Cnt_While_Col += 1
			}
		}
	}
	Return

; -----------------------------------------------------------------------------------------------	
Matrix_ROWINS:
	;
	;  Writes to Cnt_While_Row
	;
	; If ( Matrix_Debug )
	; MsgBox,, Sub Matrix_Operate,  now to delete: index %Cnt_While_Row%  %Matrix_Content_1% = %Matrix_IO_Value_1%
	Cnt_While_Col := 1
	While, Cnt_While_Col <= Matrix__Cols
	{
		%Pa_Arr_Name%_%Cnt_While_Row%_%Cnt_While_Col% := %Pa_IO_Name%_%Cnt_While_Col%
		; value := %Pa_IO_Name%_%Cnt_While_Col%
		; If ( Matrix_Debug )
		; MsgBox,, Sub Matrix_Operate,  %Cnt_While_Row%_%Cnt_While_Col% :  %value%
		Cnt_While_Col += 1
	}
	Matrix_Found := 1
	Matrix_Return := Cnt_While_Row
	Return

	
; -----------------------------------------------------------------------------------------------	
}

/*
 *************************************************************************
 */
Matrix_Test()
{
Global

Goto Start_Here

Matrix_Dim = 2
N1 = 1
N2 = 2

; initialization
AW_InOut_1 =
AW_InOut_2 = %Matrix_Dim%
Matrix_Operate( "INIT", "AW_InOut", "AW_Matrix" )

AW_InOut_%N1% = Tabelle-1
AW_InOut_%N2% = 101
Matrix_Operate( "INS", "AW_InOut", "AW_Matrix" )

AW_InOut_%N1% = Tabelle-2
AW_InOut_%N2% = 102
Matrix_Operate( "INS", "AW_InOut", "AW_Matrix" )

AW_InOut_%N1% = Tabelle-3
AW_InOut_%N2% = 103
Matrix_Operate( "INS", "AW_InOut", "AW_Matrix" )

AW_InOut_%N1% = Tabelle-4
AW_InOut_%N2% = 104
Matrix_Operate( "INS", "AW_InOut", "AW_Matrix" )

listvars

	Cnt_While_Row := 1
	Data = 
	While, Cnt_While_Row <= AW_Matrix__Rows
	{
		Data1 := AW_Matrix_%Cnt_While_Row%_1
		Data2 := AW_Matrix_%Cnt_While_Row%_2
		Data = %Data%Row %Cnt_While_Row%:  %Data1% %Data2% `n
		Cnt_While_Row += 1
	}
	MsgBox %Data%

AW_InOut_%N1% = Tabelle-3
AW_InOut_%N2% = 10003
var := Matrix_Operate( "INS", "AW_InOut", "AW_Matrix" )
listvars
msgbox replace Var %AW_InOut_2%: %var%

AW_InOut_%N1% = Tabelle-3
AW_InOut_%N2% = nein
listvars
sleep 2000
var := Matrix_Operate( "FND", "AW_InOut", "AW_Matrix" )
listvars
msgbox find Var %AW_InOut_2%: %var%

AW_InOut_%N1% = Tabelle-2
AW_InOut_%N2% = 102
var := Matrix_Operate( "DEL", "AW_InOut", "AW_Matrix" )
listvars
msgbox delete Var %AW_InOut_2%: %var%

AW_InOut_%N1% = Tabelle-5
AW_InOut_%N2% = 10005
var := Matrix_Operate( "INS", "AW_InOut", "AW_Matrix" )
listvars
msgbox insert innerhalb Var %AW_InOut_2%: %var%

AW_InOut_1 = _K.DAT
Matrix_Operate( "WR", "AW_InOut", "AW_Matrix" )

AW_Matrix_1_1=
AW_Matrix_1_2=
AW_Matrix_2_1=
AW_Matrix_2_2=
AW_Matrix__Rows=
AW_Matrix__Cols=
listvars
sleep 2000
msgbox write

Matrix_Operate( "RD", "AW_InOut", "AW_Matrix" )
listvars
msgbox read

; ------------------------------------------
Start_Here:

Rows = 5
Cols = 3

Mat_IO_1 := 
Mat_IO_2 := Rows
Mat_IO_3 := Cols
Matrix_Operate( "INIT", "Mat_IO", "Mat" )


Row := 1
While, Row <= Rows
{
	Col := 1
	While, Col <= Cols
	{
		Mat_%Row%_%Col% := Row * 1000 + Col
		Col += 1
	}
	Row += 1
}

/*
Mat_IO_1 := 2001
Mat_IO_2 :=        ; or: 2002
Mat_IO_3 := 2003
RowFound := Matrix_Operate( "FND*", "Mat_IO", "Mat" )

ListVars
msgbox FND* %Rows% %Cols%    %RowFound%
*/

Mat_IO_1 := 5
RowNoFnd := Matrix_Operate( "RowDel", "Mat_IO", "Mat" )
msgbox ROWDEL %RowNoFnd%

Loop
{
	Mat_IO_1 := A_Index
	RowNoFnd := Matrix_Operate( "RowGet", "Mat_IO", "Mat" )
	msgbox RowGet %RowNoFnd%/%Rows%: "%Mat_IO_1%" "%Mat_IO_2%" 
	If ( RowNoFnd = 0 )
		Break
}
MSGBOX	 ENDE ROWGET


ExitApp, 0
}

/*
 *************************************************************************
 */
mMatrix__Filename( Action, Filename )
{
	Global 
	
	If ( Filename = "" )
	{
		Matrix__File := %Pa_Arr_Name%__File
	}
	Else
	{
		Matrix__File := Filename
	}
	If ( Matrix__File = "" )
	{
		; Tooltip Filename not defined for function "%Action%"
		Return 1   ; just don't do it

		MsgBox 16
		, Error in method "Matrix_Operate" 
		, Filename not defined for function "%Action%"
		Return 1
	}
	Return 0
}
; End of method mMatrix__Filename

/*
===========================================================

Matrix_1_Operate( "INS", 101, "AW_Matrix" )
Matrix_1_Operate( "INS", 102, "AW_Matrix" )
Matrix_1_Operate( "INS", 103, "AW_Matrix" )
Matrix_1_Operate( "INS", 104, "AW_Matrix" )
listvars
msgbox insert Var: %var%

var := Matrix_1_Operate( 2, 103, "AW_Matrix" )
listvars
msgbox find Var: %var%

var := Matrix_1_Operate( 3, 102, "AW_Matrix" )
listvars
msgbox delete Var: %var%

ExitApp, 0

===========================================================
*/
